@@ -16,7 +16,7 @@ limitations under the License.
 
 import os
 import json
-from typing import Union, Dict, List
+from typing import Union
 import datetime
 from typing import List, Dict
 from json import JSONEncoder
@@ -25,10 +25,14 @@ import yaml
 import numpy as np
 
 
+supported_meta_formats = ('.json', '.yml')
+
+
 class CustomEncoder(JSONEncoder):
     def default(self, obj):
         if isinstance(obj, type):
             return str(obj)
+
         if isinstance(obj, (datetime.datetime, datetime.date, datetime.time)):
             return obj.isoformat()
 
@@ -68,6 +72,12 @@ class BaseHandler:
     def write(self, path, obj, overwrite=True) -> None:
         raise NotImplementedError()
 
+    def _raise_io_error(self, path, exc):
+        # Any file decoding errors will be
+        # prepended with filepath for user
+        # to be able to identify broken file
+        raise IOError(f'Error while reading file `{path}`') from exc
+
 
 class JSONHandler(BaseHandler):
     """
@@ -80,19 +90,28 @@ class JSONHandler(BaseHandler):
         Parameters
         ----------
         path:
-            Path to the file. If no extension provided, then .json will be added
+            Path to the file. If no extension provided,
+            then .json will be added
+
+        Raises
+        ------
+        IOError
+            when decoding errors occur
         """
         _, ext = os.path.splitext(path)
         if ext == '':
             path += '.json'
 
         with open(path, 'r') as meta_file:
-            meta = json.load(meta_file)
-            if isinstance(meta, str):
-                meta = json.loads(meta)
+            try:
+                meta = json.load(meta_file)
+                if isinstance(meta, str):
+                    meta = json.loads(meta)
+            except json.JSONDecodeError as e:
+                self._raise_io_error(path, e)
             return meta
 
-    def write(self, name, obj:List[Dict], overwrite=True) -> None:
+    def write(self, name, obj: List[Dict], overwrite=True) -> None:
         """
         Writes json to path using custom encoder
         """
@@ -112,13 +131,21 @@ class YAMLHandler(BaseHandler):
         ----------
         path:
             Path to the file. If no extension provided, then .yml will be added
+
+        Raises
+        ------
+        IOError
+            when decoding errors occur
         """
         _, ext = os.path.splitext(path)
         if ext == '':
             path += '.yml'
 
         with open(path, 'r') as meta_file:
-            meta = yaml.safe_load(meta_file)
+            try:
+                meta = yaml.safe_load(meta_file)
+            except yaml.YAMLError as e:
+                self._raise_io_error(path, e)
             return meta
 
     def write(self, path, obj, overwrite=True) -> None:
@@ -133,7 +160,8 @@ class YAMLHandler(BaseHandler):
 class TextHandler(BaseHandler):
     def read(self, path) -> Dict:
         """
-        Reads text file from path and returns dict in the form {path: 'text from file'}
+        Reads text file from path and returns dict
+        in the form {path: 'text from file'}
 
         Parameters
         ----------
@@ -146,7 +174,8 @@ class TextHandler(BaseHandler):
             return meta
 
     def write(self, path, obj, overwrite=True) -> None:
-        raise NotImplementedError('MetaHandler does not write text files, only reads')       
+        raise NotImplementedError(
+            'MetaHandler does not write text files, only reads')
 
 
 class MetaHandler:
